*******************************************************************************
*** Generate weights matrices: spatial robustness project with Ed Goldring and Brandon Park, Party Politics
***
***
*******************************************************************************

*** Set up working directory
*cd ""

*******************************************************************************
************************** GERMANY ********************************************
*******************************************************************************

*** Turn the monadic dataset into dyadic: party/ts
use "Germany.dta", clear

sort issue ts party
format ts %12.0g

keep if issue == 4

*** Drop the first year
drop if ts <= 492

keep issue ts party

*** Generate the number of observations per issue/ts
tempvar noobsvar
bys issue ts: egen `noobsvar' = count(party)

*** Generate the dyadic dataset
levelsof ts, local(T)
qui foreach t of local T {
	preserve
		keep if ts == `t'
		
		local noobs = `noobsvar'[1]
		expand `noobs'
		sort party
			
		levelsof party, local(P)
		egen party2 = fill(`P' `P')
		
		tempfile ts`t'
		save `ts`t''				
	restore
}

*** Append all the datasets together
qui foreach t of local T {
	local first_ts: word 1 of `T'
	if `t' == `first_ts' {
		use `ts`t'', clear
	}
	else {
		append using `ts`t''
	}
}

format ts %tm
lab val party2 party2


*** Generate the contiguity variable
gen contiguity = 1 if ts <= tm(2002m8) & ((party == 1 & party2 == 2) | (party == 2 & party2 == 1) | (party == 3 & party2 == 2) | (party == 4 & party2 == 3) | (party == 2 & party2 == 3) | (party == 3 & party2 == 4))
replace contiguity = 1 if (ts >= tm(2002m9) & ts <= tm(2009m8)) & ((party == 1 & party2 == 2) | (party == 2 & party2 == 1) | (party == 3 & party2 == 2) | (party == 4 & party2 == 3) | (party == 2 & party2 == 3) | (party == 3 & party2 == 4))
replace contiguity = 1 if ts >= tm(2009m9) & ((party == 1 & party2 == 2) | (party == 2 & party2 == 1) | (party == 1 & party2 == 3) | (party == 4 & party2 == 3) | (party == 3 & party2 == 4) | (party == 3 & party2 == 1))
recode contiguity (.=0)
	
*** Generate the coalition variables
gen coalition = 0
replace coalition = 1 if ((party == 1 & party2 == 2) | (party == 2 & party2 == 1)) & ts <= tm(2002m9)
replace coalition = 2 if ((party == 1 & party2 == 2) | (party == 2 & party2 == 1)) & (ts >= tm(2002m10) & ts <= tm(2005m9))
replace coalition = 3 if ((party == 2 & party2 == 4) | (party == 4 & party2 == 2)) & (ts >= tm(2005m10) & ts <= tm(2009m9))
replace coalition = 4 if ((party == 3 & party2 == 4) | (party == 4 & party2 == 3)) & (ts >= tm(2009m10) & ts <= tm(2013m9))
recode coalition (2/4=1)

*** Generate the dyadic dataset
levelsof ts, local(T)
qui foreach t of local T {
	preserve
		keep if ts == `t'
		
		foreach w in contiguity coalition {
			rename `w' `w'`t'
		}
		reshape wide contiguity`t' coalition`t', i(party) j(party2)
		
		tempfile ts`t'
		save `ts`t''				
	restore
}

*** Append all the datasets together
qui foreach t of local T {
	local first_ts: word 1 of `T'
	if `t' == `first_ts' {
		use `ts`t'', clear
	}
	else {
		append using `ts`t''
	}
}

gen id = _n
order issue ts party id

qui foreach w in contiguity coalition {
	preserve
		keep id `w'*
		sort id
		
		foreach v of varlist `w'* {
			recode `v' (.=0)
		}

		tempvar rtot 
		egen `rtot' = rowtotal(`w'*)
		recode `rtot' (.=0)
		foreach v of varlist `w'* {
			replace `v' = `v' / `rtot'
			recode `v' (.=0)
		}
		
		cap drop __*
		saveold "W\W`w'_rs", replace version(13)
	restore
}


